Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsSafePluginName ¶
IsSafePluginName checks if the plugin Name is save to use.
Types ¶
type FileOperation ¶
FileOperation TODO(lbb)
type Platform ¶
type Platform struct {
Head string `json:"head,omitempty"`
URI string `json:"uri,omitempty"`
Sha256 string `json:"sha256,omitempty"`
Selector *metav1.LabelSelector `json:"selector,omitempty"`
Files []FileOperation `json:"files"`
// Bin specifies the path to the plugin executable.
// The path is relative to the root of the installation folder.
// The binary will be linked after all FileOperations are executed.
Bin string `json:"bin"`
}
Platform TODO(lbb)
type Plugin ¶
type Plugin struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PluginSpec `json:"spec"`
}
Plugin is a top-level type. TODO(lbb): Add deepcopy code generation.
type PluginList ¶
type PluginList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Plugin `json:"items"`
}
PluginList TODO(lbb)
type PluginSpec ¶
type PluginSpec struct {
Version string `json:"version,omitempty"`
ShortDescription string `json:"shortDescription,omitempty"`
Description string `json:"description,omitempty"`
Caveats string `json:"caveats,omitempty"`
Platforms []Platform `json:"platforms,omitempty"`
}
PluginSpec TODO(lbb)
Click to show internal directories.
Click to hide internal directories.